"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sanitizeExpressMiddlewareAsync = exports.sanitizeExpressMiddleware = exports.sanitizeJsonAsync = exports.sanitizeJsonSync = void 0;
const sanitizer_1 = require("./sanitizer");
const worker_threads_1 = require("worker_threads");
/**
 * Sanitize any json schema.
 * By walk on all json tree and cleaning an existing string.
 * @param jsonSchema Json to sanitize.
 * @param cleanOptions 'sanitize-html' lib options.
 */
function sanitizeJsonSync(jsonSchema, cleanOptions = undefined) {
    sanitizer_1.sanitizeJson(jsonSchema, cleanOptions);
}
exports.sanitizeJsonSync = sanitizeJsonSync;
/**
 * Sanitize any json schema async.
 * By walk on all json tree and cleaning an existing string.
 * @param jsonSchema Json to sanitize.
 * @param cleanOptions 'sanitize-html' lib options.
 * @returns the sanitized json object.
 */
async function sanitizeJsonAsync(jsonSchema, cleanOptions = undefined) {
    return new Promise((resolve, reject) => {
        const worker = new worker_threads_1.Worker(__dirname + '/sanitizer.js', { workerData: { jsonSchema, cleanOptions } });
        worker.on('message', (sanitizedSchema) => {
            resolve(sanitizedSchema);
        });
        worker.on('error', reject);
        worker.on('exit', (code) => {
            if (code != 0)
                console.error(new Error(`Worker stopped with exit code ${code}`));
        });
    });
}
exports.sanitizeJsonAsync = sanitizeJsonAsync;
/**
 * Sanitize any request.body schema.
 * @param request express request.
 * @param response express response.
 * @param next express next.
 * @param cleanOptions optional 'sanitize-html' lib options, if undefined using default.
 */
function sanitizeExpressMiddleware(request, response, next, cleanOptions = undefined) {
    if (typeof request.body !== 'string') {
        sanitizer_1.sanitizeJson(request.body, cleanOptions);
    }
    else {
        /**
         * 'SanitizeValidJson' assume that parameter is passing by ref.
         * So if schema is string, the original request string will not changed.
         */
        const schema = { body: request.body };
        sanitizer_1.sanitizeJson(schema, cleanOptions);
        request.body = schema.body;
    }
    next();
}
exports.sanitizeExpressMiddleware = sanitizeExpressMiddleware;
;
/**
 * Sanitize any request.body schema async.
 * @param request express request.
 * @param response express response.
 * @param next express next.
 * @param cleanOptions optional 'sanitize-html' lib options, if undefined using default.
 */
async function sanitizeExpressMiddlewareAsync(request, response, next, cleanOptions = undefined) {
    if (typeof request.body !== 'string') {
        request.body = await sanitizeJsonAsync(request.body, cleanOptions);
    }
    else {
        /**
         * 'SanitizeValidJson' assume that parameter is passing by ref.
         * So if schema is string, the original request string will not changed.
         */
        const schema = { body: request.body };
        const sanitizedSchema = await sanitizeJsonAsync(schema, cleanOptions);
        request.body = sanitizedSchema.body;
    }
    next();
}
exports.sanitizeExpressMiddlewareAsync = sanitizeExpressMiddlewareAsync;
;
//# sourceMappingURL=index.js.map